# -*- coding: utf-8 -*-
from django.db import models


# this module contains an empty model to use Django's ModelAdmin to add a view to the admin
# without too much hassle
class Status(models.Model):
    pass
